==> haskell-data-accessor-transformers-0.2.1.7-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-accessor-transformers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-accessor-transformers
version: 0.2.1.7
id: data-accessor-transformers-0.2.1.7-6TVC9nFjSqUC6vJHuIemG9
key: data-accessor-transformers-0.2.1.7-6TVC9nFjSqUC6vJHuIemG9
license: BSD3
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://www.haskell.org/haskellwiki/Record_access
synopsis: Use Accessor to access state in transformers State monad
description:
    Use Accessor to access state in transformers State monad
category: Data
author: Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
exposed-modules:
    Data.Accessor.Monad.Trans.RWS Data.Accessor.Monad.Trans.State
hidden-modules: Data.Accessor.Monad.Trans.Example
abi: a5cac4851e989c261bb06d029c2abfbc
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/data-accessor-transformers-0.2.1.7
library-dirs: /usr/lib/ghc-8.0.1/site-local/data-accessor-transformers-0.2.1.7
data-dir: /usr/share/arm-linux-ghc-8.0.1/data-accessor-transformers-0.2.1.7
hs-libraries: HSdata-accessor-transformers-0.2.1.7-6TVC9nFjSqUC6vJHuIemG9
depends:
    base-4.9.0.0 data-accessor-0.2.2.7-8YIdFyGw7Iv38wc1N9wMCB
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-data-accessor-transformers/html/data-accessor-transformers.haddock
haddock-html: /usr/share/doc/haskell-data-accessor-transformers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-accessor-transformers-0.2.1.7-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-accessor-transformers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-accessor-transformers
version: 0.2.1.7
id: data-accessor-transformers-0.2.1.7-6YP6JqsIeFrBCN7cotgZiz
key: data-accessor-transformers-0.2.1.7-6YP6JqsIeFrBCN7cotgZiz
license: BSD3
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://www.haskell.org/haskellwiki/Record_access
synopsis: Use Accessor to access state in transformers State monad
description:
    Use Accessor to access state in transformers State monad
category: Data
author: Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
exposed-modules:
    Data.Accessor.Monad.Trans.RWS Data.Accessor.Monad.Trans.State
hidden-modules: Data.Accessor.Monad.Trans.Example
abi: 9eebe005686807c2c5f5d903205249d0
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/data-accessor-transformers-0.2.1.7
library-dirs: /usr/lib/ghc-8.0.2/site-local/data-accessor-transformers-0.2.1.7
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/data-accessor-transformers-0.2.1.7
hs-libraries: HSdata-accessor-transformers-0.2.1.7-6YP6JqsIeFrBCN7cotgZiz
depends:
    base-4.9.1.0 data-accessor-0.2.2.7-EIyoGWJa6mi6QAVcUY9dHP
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-data-accessor-transformers/html/data-accessor-transformers.haddock
haddock-html: /usr/share/doc/haskell-data-accessor-transformers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
